@@ -199,7 +199,8 @@ class kafka_mdml_producer:
         producer_config = {
             'bootstrap.servers': f'{kafka_host}:{kafka_port}',
             'value.serializer': json_serializer,
-            'acks': acks
+            'acks': acks,
+            'max.in.flight.requests.per.connection': 1000000
         }
         self.producer = SerializingProducer(producer_config)
     def produce(self, data):
